@@ -226,7 +226,7 @@ impl StarshipConfig {
         } else {
             // Default to using ~/.config/starship.toml
             log::debug!("STARSHIP_CONFIG is not set");
-            let config_path = dirs_next::home_dir()?.join(".config/starship.toml");
+            let config_path = utils::home_dir()?.join(".config/starship.toml");
             let config_path_str = config_path.to_str()?.to_owned();
             log::debug!("Using default config path: {}", config_path_str);
             config_path_str
@@ -342,6 +342,10 @@ impl StarshipConfig {
     pub fn get_custom_modules(&self) -> Option<&toml::value::Table> {
         self.get_config(&["custom"])?.as_table()
     }
+    /// Get the table of all the registered env_var modules, if any
+    pub fn get_env_var_modules(&self) -> Option<&toml::value::Table> {
+        self.get_config(&["env_var"])?.as_table()
+    }
 
     pub fn get_root_config(&self) -> StarshipRootConfig {
         if let Some(root_config) = &self.config {
@@ -503,7 +507,7 @@ mod tests {
         rust_config.load_config(&config);
 
         assert_eq!(rust_config.symbol, "T ");
-        assert_eq!(rust_config.disabled, true);
+        assert!(rust_config.disabled);
         assert_eq!(rust_config.some_array, vec!["A"]);
     }
 
@@ -631,7 +635,7 @@ mod tests {
     #[test]
     fn test_from_bool() {
         let config = Value::Boolean(true);
-        assert_eq!(<bool>::from_config(&config).unwrap(), true);
+        assert!(<bool>::from_config(&config).unwrap());
     }
 
     #[test]
