@@ -2,7 +2,7 @@ use process_control::{ChildExt, Timeout};
 use std::fmt::Debug;
 use std::fs::read_to_string;
 use std::io::Result;
-use std::path::Path;
+use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
 use std::time::{Duration, Instant};
 
@@ -414,6 +414,10 @@ fn render_time_component((component, suffix): (&u128, &&str)) -> String {
     }
 }
 
+pub fn home_dir() -> Option<PathBuf> {
+    directories_next::BaseDirs::new().map(|base_dirs| base_dirs.home_dir().to_owned())
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
